@@ -4,7 +4,7 @@ use strict;
 # If you change the class path take a look in get_defaults too, please!
 package Munin::Common::Defaults;
 
-# $Id: Defaults.pm 2951 2009-11-10 20:13:54Z knuthaug $
+# $Id$
 
 use English qw(-no_match_vars);
 use File::Basename qw(dirname);
@@ -25,8 +25,10 @@ our $MUNIN_DOCDIR     = '';
 our $MUNIN_LIBDIR     = '';
 our $MUNIN_HTMLDIR    = '';
 our $MUNIN_CGIDIR     = '';
+our $MUNIN_CGITMPDIR     = '';
 our $MUNIN_DBDIR      = '';
 our $MUNIN_PLUGSTATE  = ''; 
+our $MUNIN_SPOOLDIR   = '';
 our $MUNIN_MANDIR     = '';
 our $MUNIN_LOGDIR     = "$COMPONENT_ROOT/log/";
 our $MUNIN_STATEDIR   = ''; 
@@ -90,7 +92,7 @@ scripts.
 
 =head1 PACKAGE VARIABLES
 
-See L<http://munin.projects.linpro.no/wiki/MuninInstallProcedure> for
+See L<http://munin-monitoring.org/wiki/MuninInstallProcedure> for
 more information on the variables provided by this package.
 
 
