@@ -10,6 +10,7 @@ use warnings;
 use English qw(-no_match_vars);
 
 use Munin::Node::Config;
+use Munin::Common::Daemon;
 use Munin::Common::Defaults;
 use Munin::Common::Timeout;
 use Munin::Common::TLSServer;
@@ -52,6 +53,8 @@ sub pre_loop_hook {
 
     $services->prepare_plugin_environment(keys %services);
     _add_services_to_nodes(keys %services);
+    # the port is bound, the service is prepared: we can start accepting requests
+    Munin::Common::Daemon::emit_sd_notify_message();
     return $self->SUPER::pre_loop_hook();
 }
 
@@ -153,6 +156,15 @@ sub process_request
 }
 
 
+# This method is used by Net::Server for retrieving default values (in case they are not specified
+# in the given "conf_file").
+sub default_values {
+    return {
+        port => 4949,
+    };
+}
+
+
 sub _process_command_line {
     my ($session, $cmd_line) = @_;
 
@@ -443,5 +455,7 @@ Logs the source of rejected connections.
 
 Processes the request.
 
+=back
+
 =cut
 vim: ts=4 : et : sw=4
